@@ -229,13 +229,13 @@ having some automated conveniences and defaults.
                 pagination_method = "cursor"
             else:
                 pagination_method = "time"
-            cursor = await self.GET(collection, query=query,
+            cursor = await self.GET(collection, query,
                                     limit=limit, key=sort, before=before,
                                     after=after, sort=ordering, empty=[])
         else:
             assert page >= 1, "page must be equal to or greater than 1"
             pagination_method = "offset"
-            cursor = await self.GET(collection, query=query,
+            cursor = await self.GET(collection, query,
                                     perpage=limit, key=sort, page=page,
                                     sort=ordering, empty=[])
 
@@ -269,12 +269,12 @@ having some automated conveniences and defaults.
 
             if pagination_method in ("cursor", "time"):
                 if before:
-                    check_ahead = await self.GET(collection, query=query,
+                    check_ahead = await self.GET(collection, query,
                                             limit=limit, key=sort, before=new_before, empty=0, count=True)
                     if not check_ahead:
                         new_before = None
                 elif after:
-                    check_ahead = await self.GET(collection, query=query,
+                    check_ahead = await self.GET(collection, query,
                                             limit=limit, key=sort, after=new_after, empty=0, count=True)
                     if not check_ahead:
                         new_after = None
