@@ -236,21 +236,21 @@ class SyncIOClient(MongoClient):
         if isinstance(sort, ENUM.__supertype__):
             sort = sort.value
 
-        total_docs = self.GET(collection, query=query, count=True, empty=0)
+        total_docs = self.GET(collection, query, count=True, empty=0)
 
         if not page:
             if sort == "_id":
                 pagination_method = "cursor"
             else:
                 pagination_method = "time"
-            results = self.GET(collection, query=query,
+            results = self.GET(collection, query,
                                     limit=limit, key=sort, before=before,
                                     after=after, sort=ordering, empty=[]).list()
 
         else:
             assert page >= 1, "page must be equal to or greater than 1"
             pagination_method = "offset"
-            results = self.GET(collection, query=query,
+            results = self.GET(collection, query,
                                     perpage=limit, key=sort, page=page,
                                     sort=ordering, empty=[]).list()
 
@@ -282,12 +282,12 @@ class SyncIOClient(MongoClient):
 
             if pagination_method in ("cursor", "time"):
                 if before:
-                    check_ahead = self.GET(collection, query=query,
+                    check_ahead = self.GET(collection, query,
                                             limit=limit, key=sort, before=new_before, count=True, empty=0)
                     if not check_ahead:
                         new_before = None
                 elif after:
-                    check_ahead = self.GET(collection, query=query,
+                    check_ahead = self.GET(collection, query,
                                             limit=limit, key=sort, after=new_after, count=True, empty=0)
                     if not check_ahead:
                         new_after = None
@@ -473,7 +473,7 @@ class SyncIOClient(MongoClient):
         for record in records:
             self.PATCH(collection, record, {"$unset": {field: ""}})
 
-    def UPLOAD(self, fileobj, filename:str=None, content_type:str=None, extension:str=None, **kwargs):
+    def UPLOAD(self, fileobj:typing.Union[typing.IO, str], filename:str=None, content_type:str=None, extension:str=None, **kwargs):
         """
             returns GridFS response document after successful upload
 
@@ -487,7 +487,7 @@ class SyncIOClient(MongoClient):
         metadata.update(kwargs)
         return self.FILES.upload_from_stream(filename, fileobj, metadata=metadata)
 
-    def ERASE(self, filename_or_id, revision:int=-1) -> None:
+    def ERASE(self, filename_or_id:typing.Union[str, DOC_ID], revision:int=-1) -> None:
         """
             deletes the GridFS file. if multiple revisions, deletes most recent by default.
 
@@ -498,7 +498,7 @@ class SyncIOClient(MongoClient):
         self.FILES.delete(fs_doc._id)
         fs_doc.close()
 
-    def DOWNLOAD(self, filename_or_id=None, revision:int=-1, skip:int=None, limit:int=None, sort:int=-1, **query):
+    def DOWNLOAD(self, filename_or_id:typing.Optional[typing.Union[str, DOC_ID]]=None, revision:int=-1, skip:int=None, limit:int=None, sort:int=-1, **query):
         """
             returns download stream of file if filename_or_id is provided, else returns a cursor of files matching query
         """
