@@ -26,16 +26,22 @@
 import typing
 from functools import partial
 from .utils import snake2camel
-from .utils import yaml_dump, yaml_load, sort_list
+from .utils import (
+                    json_dump,
+                    json_load,
+                    yaml_dump,
+                    yaml_load,
+                    sort_list,
+                    )
 from .vars import (
-                        DOC_ID,
-                        DETAILS,
-                        PAGINATION_SORT_FIELDS,
-                        YAML,
-                        JSON,
-                        ASCENDING,
-                        DESCENDING,
-                        )
+                    DOC_ID,
+                    DETAILS,
+                    PAGINATION_SORT_FIELDS,
+                    YAML,
+                    JSON,
+                    ASCENDING,
+                    DESCENDING,
+                    )
 from pymongo.cursor import Cursor
 try:
     from pydantic import BaseConfig, BaseModel
@@ -48,6 +54,8 @@ try:
         * accept fields using snake_case or camelCase keys
         * use camelCase keys in the generated OpenAPI spec (when supported)
         * have orm_mode on by default
+
+        - from fastapi-utils
         """
 
         class Config(BaseConfig):
@@ -66,6 +74,8 @@ except:
         * accept fields using snake_case or camelCase keys
         * use camelCase keys in the generated OpenAPI spec (when supported)
         * create an orm_mode Config attrib and have it on by default
+
+        - from fastapi-utils
         """
 
         class Config():
@@ -74,7 +84,23 @@ except:
             alias_generator = partial(snake2camel, start_lower=True)
 
 
+# INFO: required to desired web response documents
+class MetaConfig(type):
+    def __str__(cls):
+        return json_dump({
+                        attr: value for attr, value in cls
+                    }, pretty=True)
+
+    def __iter__(cls):
+        for attr, value in cls.__dict__.items():
+            if attr.isupper():
+                yield attr, value
+
+
 class _GenericResponse(DefaultModel):
+    def __repr__(self):
+        return "GenericResponse"
+
     class Config:
         schema_extra = {
             'example': [
@@ -116,6 +142,9 @@ class _StandardResponse(DefaultModel):
     data: typing.Union[typing.Dict, typing.List, typing.Text, int, float, bool]
     details: DETAILS = DETAILS(...)
 
+    def __repr__(self):
+        return "StandardResponse"
+
     class Config:
         schema_extra = {
             'example': [
@@ -212,8 +241,15 @@ class MongoListResponse(list):
         else:
             self.clear()
 
-    def close(self):
-        """Closes cursor or clears list"""
+    def get(self) -> typing.Union[Cursor, typing.List]:
+        """returns cursor or list instance"""
+        if self._cursor:
+            return self._cursor
+        else:
+            return self
+
+    def close(self) -> None:
+        """closes cursor or clears list"""
         if self._cursor:
             self._cursor.close()
         else:
@@ -227,12 +263,12 @@ class MongoListResponse(list):
         # ~ else:
             # ~ return self._index + 1
 
-    def rewind(self):
+    def rewind(self) -> None:
         """rewinds cursor, if any"""
         if self._cursor:
             self._cursor.rewind()
 
-    def distinct(self, field:str="_id") -> list:
+    def distinct(self, field:str="_id") -> typing.List[typing.Any]:
         """returns list of distinct values based on field, defaults to '_id'. supports dot notation for nested values."""
         if self._cursor:
             self._cursor.rewind()
@@ -274,12 +310,21 @@ class MongoListResponse(list):
     def count(self) -> int:
         """returns the count of the number of records in cursor or list results"""
         if self._cursor:
-            self._cursor.rewind()
-            return self._cursor.count()
+            try:
+                self._cursor.rewind()
+                return self._cursor.count(with_limit_and_skip=True)
+            except:
+                col = self._cursor._Cursor__collection
+                query = self._cursor._Cursor__spec or {}
+                limit = self._cursor._Cursor__limit
+                sort = self._cursor._Cursor__ordering
+                if sort:
+                    sort = sort.items()
+                return col.count_documents(query, limit=limit, hint=sort)
         else:
             return len(self)
 
-    def sort(self, sort:int=1, key:str="_id"):
+    def sort(self, sort:int=1, key:str="_id") -> 'self':
         """sorts cursor results or list results, default is cervmongo.ASC (int 1)
 
         Options:
@@ -300,7 +345,7 @@ class MongoListResponse(list):
                 super().sort(key=lambda item, field=key: sort_list(item, field))
             return self
 
-    def list(self) -> list:
+    def list(self) -> typing.List[typing.Dict]:
         """returns a new list representation of the current cursor"""
         if self._cursor:
             self._cursor.rewind()
